@@ -13,8 +13,8 @@ class Io(metaclass=ABCMeta):
 
     @abstractmethod
     def read(self):
-        return
+        pass
 
     @abstractmethod
     def write(self):
-        return
+        pass
